@@ -113,13 +113,14 @@ class Scene(NodeMixin):
 
     @typic.cached_property
     def col(self) -> str:
-        pre = ""
-        if self.act:
-            if NodeType.PROL in self.act or NodeType.EPIL in self.act:
-                pre = self.act[0].upper()
+        pre = self.act or ""
+        if pre:
+            pieces = self.act.split("-")
+            if len(pieces) == 2:
+                pre = f"{pieces[1].upper()}: "
             else:
-                pre = self.act.split("-")[-1].upper()
-        return f"{pre}.{roman.numeral(self.num).lower()}"
+                pre = f"{pieces[0].title()}: "
+        return f"{pre}{roman.numeral(self.num).lower()}"
 
     @classmethod
     def from_node(cls, node: "GenericNode") -> "Scene":
@@ -169,8 +170,14 @@ class Prologue(NodeMixin):
 
     @typic.cached_property
     def col(self):
-        pre = f"{self.act.split('-')[-1].upper()}." if self.act else ""
-        return f"{pre}{self.type.value[0].upper()}"
+        pre = self.act or ""
+        if pre:
+            pieces = self.act.split("-")
+            if len(pieces) == 2:
+                pre = f"{pieces[1].upper()}: "
+            else:
+                pre = f"{pieces[0].title()}: "
+        return f"{pre}{self.type.title()}"
 
     @classmethod
     def from_node(cls, node: "GenericNode") -> "Prologue":
@@ -212,7 +219,7 @@ class Intermission(NodeMixin):
 
     @typic.cached_property
     def col(self):
-        return "INT"
+        return titleize(self.text)
 
 
 @typic.klass(unsafe_hash=True)
